@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -80,7 +81,7 @@ namespace OrthancWSI
     }
 
 
-    static void PrintProgress(Orthanc::BagOfTasksProcessor::Handle* handle,
+    static void PrintProgress(BagOfTasksProcessor::Handle* handle,
                               bool* done)
     {
       unsigned int previous = 0;
@@ -99,7 +100,7 @@ namespace OrthancWSI
     }
 
 
-    void Execute(Orthanc::BagOfTasks& tasks,
+    void Execute(BagOfTasks& tasks,
                  unsigned int threadsCount)
     {
       if (threadsCount > 1)
@@ -107,8 +108,8 @@ namespace OrthancWSI
         // Submit the tasks to a newly-created processor
         LOG(WARNING) << "Running " << tasks.GetSize() << " tasks";
         LOG(WARNING) << "Using " << threadsCount << " threads for the computation";
-        Orthanc::BagOfTasksProcessor processor(threadsCount);
-        std::unique_ptr<Orthanc::BagOfTasksProcessor::Handle> handle(processor.Submit(tasks));
+        BagOfTasksProcessor processor(threadsCount);
+        std::unique_ptr<BagOfTasksProcessor::Handle> handle(processor.Submit(tasks));
 
         // Start a thread to display the progress
         bool done = false;
@@ -145,7 +146,7 @@ namespace OrthancWSI
         // No multithreading
         while (!tasks.IsEmpty())
         {
-          std::unique_ptr<Orthanc::ICommand> task(tasks.Pop());
+          std::unique_ptr<ICommand> task(tasks.Pop());
           if (task->Execute())
           {
             unsigned int progress = static_cast<unsigned int>(100.0f * 
@@ -220,6 +221,7 @@ namespace OrthancWSI
         << "Copyright (C) 2012-2016 Sebastien Jodogne, "
         << "Medical Physics Department, University Hospital of Liege (Belgium)" << std::endl
         << "Copyright (C) 2017-2021 Osimis S.A. (Belgium)" << std::endl
+        << "Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain (Belgium)" << std::endl
         << "Licensing AGPL: GNU AGPL version 3 or later <http://gnu.org/licenses/agpl.html>." << std::endl
         << "This is free software: you are free to change and redistribute it." << std::endl
         << "There is NO WARRANTY, to the extent permitted by law." << std::endl
