@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -37,7 +38,7 @@ namespace OrthancWSI
 
     void GlobalFinalize();
 
-    void Execute(Orthanc::BagOfTasks& tasks,
+    void Execute(BagOfTasks& tasks,
                  unsigned int threadsCount);
 
     void ParseColor(uint8_t& red,
