@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -160,7 +161,7 @@ namespace OrthancWSI
   }
 
 
-  void ReconstructPyramidCommand::PrepareBagOfTasks(Orthanc::BagOfTasks& tasks,
+  void ReconstructPyramidCommand::PrepareBagOfTasks(BagOfTasks& tasks,
                                                     IPyramidWriter& target,
                                                     ITiledPyramid& source,
                                                     unsigned int countLevels,
