@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,7 +28,7 @@
 
 namespace OrthancWSI
 {
-  class TranscodeTileCommand : public Orthanc::ICommand
+  class TranscodeTileCommand : public ICommand
   {
   private:
     IPyramidWriter& target_;
@@ -51,7 +52,7 @@ namespace OrthancWSI
 
     virtual bool Execute() ORTHANC_OVERRIDE;
 
-    static void PrepareBagOfTasks(Orthanc::BagOfTasks& tasks,
+    static void PrepareBagOfTasks(BagOfTasks& tasks,
                                   IPyramidWriter& target,
                                   ITiledPyramid& source,
                                   const DicomizerParameters& parameters);
