@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -58,6 +59,14 @@ namespace OrthancWSI
 
     Orthanc::WebServiceParameters  orthanc_;
 
+    // New in release 1.1
+    bool                           isCytomineSource_;
+    Orthanc::WebServiceParameters  cytomineServer_;
+    int                            cytomineImageInstanceId_;
+    std::string                    cytominePublicKey_;
+    std::string                    cytominePrivateKey_;
+    ImageCompression               cytomineCompression_;
+
   public:
     DicomizerParameters();
 
@@ -248,5 +257,26 @@ namespace OrthancWSI
     {
       return iccProfile_;
     }
+
+    void SetCytomineSource(const std::string& url,
+                           const std::string& publicKey,
+                           const std::string& privateKey,
+                           int imageInstanceId,
+                           ImageCompression compression);
+
+    bool IsCytomineSource() const
+    {
+      return isCytomineSource_;
+    }
+
+    const Orthanc::WebServiceParameters& GetCytomineServer() const;
+
+    const std::string& GetCytominePublicKey() const;
+
+    const std::string& GetCytominePrivateKey() const;
+
+    int GetCytomineImageInstanceId() const;
+
+    ImageCompression GetCytomineCompression() const;
   };
 }
