@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -27,9 +28,9 @@
 
 #include <stdio.h>
 
-namespace Orthanc
+namespace OrthancWSI
 {
-  class BagOfTasksProcessor::Task : public IDynamicObject
+  class BagOfTasksProcessor::Task : public Orthanc::IDynamicObject
   {
   private:
     uint64_t                 bag_;
@@ -49,7 +50,7 @@ namespace Orthanc
       {
         return command_->Execute();
       }
-      catch (OrthancException& e)
+      catch (Orthanc::OrthancException& e)
       {
         LOG(ERROR) << "Exception while processing a bag of tasks: " << e.What();
         return false;
@@ -91,7 +92,7 @@ namespace Orthanc
   {
     while (that->continue_)
     {
-      std::unique_ptr<IDynamicObject> obj(that->queue_.Dequeue(100));
+      std::unique_ptr<Orthanc::IDynamicObject> obj(that->queue_.Dequeue(100));
       if (obj.get() != NULL)
       {
         Task& task = *dynamic_cast<Task*>(obj.get());
@@ -206,7 +207,7 @@ namespace Orthanc
   {
     if (countThreads == 0)
     {
-      throw OrthancException(ErrorCode_ParameterOutOfRange);
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
     }
 
     threads_.resize(countThreads);
