@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,13 +24,13 @@
 
 #include <IDynamicObject.h>
 
-namespace Orthanc
+namespace OrthancWSI
 {
   /**
    * This class is the base class for the "Command" design pattern.
    * http://en.wikipedia.org/wiki/Command_pattern
    **/
-  class ICommand : public IDynamicObject
+  class ICommand : public Orthanc::IDynamicObject
   {
   public:
     virtual bool Execute() = 0;
