@@ -3,6 +3,7 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2021 Osimis S.A., Belgium
+ * Copyright (C) 2021-2021 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -158,9 +159,9 @@ namespace OrthancWSI
           std::unique_ptr<DcmItem> item(new DcmItem);
 
           std::unique_ptr<DcmItem> item2(new DcmItem);
-          OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_SliceThickness, 
-                                                 boost::lexical_cast<std::string>(volume_.GetDepth()));
-          OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_PixelSpacing, spacing);
+          DicomToolbox::SetStringTag(*item2, DCM_SliceThickness, 
+                                     boost::lexical_cast<std::string>(volume_.GetDepth()));
+          DicomToolbox::SetStringTag(*item2, DCM_PixelSpacing, spacing);
 
           std::unique_ptr<DcmSequenceOfItems> sequence2(new DcmSequenceOfItems(DCM_PixelMeasuresSequence));
           if (!sequence2->insert(item2.release(), false, false).good())
